"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const grpc = require("grpc");
const protoLoader = require("@grpc/proto-loader");
class GrpcLogic {
    constructor() {
        /**
         * Instancia del servicio
         */
        this.apiProto = grpc.loadPackageDefinition(protoLoader.loadSync(path.join(__dirname, "proto", "api.proto")));
        /**
         * Instancia del servidor GRPC
         */
        this.server = null;
        /**
         * Host
         */
        this.host = "0.0.0.0";
        /**
         * Puerto del servidor GRPC
         */
        this.port = "50051";
        this.server = new grpc.Server();
        // Configurar el servidor
        this.server.bind(this.getHostname(), grpc.ServerCredentials.createInsecure() // Dejar como inseguro
        );
    }
    /**
     * Metodo para retornar los datos de conexion.
     */
    getHostname() {
        return `${this.host}:${this.port}`;
    }
    /**
     *  Metodo para iniciar el servidor GRPC
     */
    start() {
        this.server.start();
    }
    /**
     * Metodo para vincular la operacion
     * @param fnc Meotodo a vincular para la recepcion de mensajes
     */
    bind(fnc) {
        this.server.addService(this.apiProto.Microservice.service, {
            Execute: (call, callback) => {
                fnc(call.request, (resp) => {
                    const respService = resp.response.data.response;
                    let error = null;
                    // Validar si ocurrio un error
                    try {
                        if (respService.hasOwnProperty("errorCode")) {
                            error = {
                                code: grpc.status.INTERNAL,
                                message: respService.userMessage,
                                status: grpc.status.INTERNAL,
                            };
                        }
                    }
                    catch (errorR) {
                        //
                    }
                    // Ejecutar el callback
                    callback(error, resp.response);
                });
            },
        });
    }
}
exports.default = GrpcLogic;
